#ifndef INPAINT_H
#define INPAINT_H

// $Id$

//////////////////////////////////////////////////////////////////////////

#include <cv.h>

//////////////////////////////////////////////////////////////////////////

// Multiscale-Multichannel Inpainting

class mm_inpaint_func
{
protected:
  void * _intern; // opaque INTERNAL DATA

public:
  mm_inpaint_func(); // NO MEMORY ALLOCATED
  virtual ~mm_inpaint_func();

public:
  mm_inpaint_func(mm_inpaint_func const & func);
  mm_inpaint_func & operator=(mm_inpaint_func const & func);

public:
  void reset(); // DEALLCATES MEMORY (drops internal data)

public:
  // ALLOCATES and REALLOCATES MEMORY as needed

  // the input frames are scaled by 'lambda' on each level
  // works with multichannel images (input, output)
  // the channels are weighted to define a 'color space'
  // the weights scale as 'pow(lambda, level * exponent)'
  // L1 norm assumed in the 'color space' (sum of absolute values)
  // the 'mask' must be single channeled

  // PARAMETERS:

  // it_num = number of iteration steps (on each scale)
  // lev_num = scales (or levels) used to process the frames
  // lambda = scaling factor (switching levels downwards)
  // alpha = diffusion parameter

  void operator()(
    CvArr const * input, CvArr const * mask, CvArr * output,
    int it_num, int lev_num, double lambda, double alpha, // parameters
    double const * channel_weights = 0, // multiplication factor
    double const * scaling_exponents = 0 // weights scale with levels
  );
};

//////////////////////////////////////////////////////////////////////////

#endif // INPAINT_H
